PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/quadrature.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Namespaces | Variables
quadrature.py File Reference

## Namespaces
| pawpyseed.core.quadrature

## Variables
int | pawpyseed.core.quadrature.MAXSIZE = 100
| pawpyseed.core.quadrature.f = open("quadrature.c", "w")
list | pawpyseed.core.quadrature.x = []
| pawpyseed.core.quadrature.currstr = str(x[i][0].tolist()).replace("[", "{").replace("]", "}")